@@ -135,7 +135,7 @@ def ident(panelfile, pnadc, delimiter=','):
                                                      + 'trimestral.json'))))
         archive = ZipFile(panelfile, 'a', ZIP_DEFLATED)
         start = time()
-        print('\nIdentificando painéis:')
+        print('Identificando painéis:')
         panelfiles.sort()
         for pfile in panelfiles:
             pid, panel = load_panel(archive, pfile, metadata, delimiter)
